import {
  select,
  json,
  tree,
  hierarchy,
  linkRadial,
  behavior,
  zoom,
  event,
  timer,
  drag
} from 'd3';

const svg = select('svg');
const width = document.body.clientWidth;
const height = document.body.clientHeight;

const margin = { top:50, right: 50, bottom: 0, left: 50};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const treeLayout = tree().size([2*Math.PI, innerHeight/2]);

const zoomG = svg
    .attr('width', width)
    .attr('height', height)
    .append('g')
    .attr("transform", "translate(" + innerWidth/2 + ", " + innerHeight/2 + ")rotate(0)");



const g = zoomG.append('g');

function rotateTree(rpm) {
			var newAngle = zoomG._groups[0][0].transform.animVal[1].angle + 120;

			zoomG.transition().duration(20000/rpm).ease(d3.easeLinear)
				.attr("transform", "translate(" + innerWidth/2 + ", " + innerHeight/2 + ")rotate(" + newAngle + ")")
				.on("end", function() {rotateTree(rpm)});
	}

rotateTree(0.2)

// svg.call(drag().on('drag', () => {
//   const theta = Math.atan2(event.y - innerHeight/2, event.x - innerWidth/2) * 180 / Math.PI
//   zoomG.attr("transform", "translate(" + innerWidth/2 + ", " + innerHeight/2 + ")rotate(" + theta+90 +")");
// }));

// svg.call(zoom().scaleExtent([1, 100].on('zoom', () => {
//   g.attr('transform', "translate(" + innerWidth/2 + ", " + innerHeight/2 + ")scale(" + event.transform.k +")");
// }));


const treedelay = 50

json('data.json')
  .then(data => {
    const root = hierarchy(data);
    const links = treeLayout(root).links();
     const linkPathGenerator = linkRadial()
        .angle(d => d.x)
        .radius(d => d.y);
  
    g.selectAll('path').data(links)
      .enter().append('path')
        .attr('d', linkPathGenerator)
  			.style("opacity", 0)
      	.transition()
      	.duration(500)
      	.delay(function(d,i) {
        				return treedelay*i; })
      	.style("opacity", 1);
  
    g.selectAll('text').data(root.descendants())
      .enter().append('text')
      .attr("transform", d => `rotate(${d.x * 180 / Math.PI - 90}) translate(${d.y},0)`)
        .attr('dy', '0.32em')
        .attr('text-anchor', d => d.children ? 'middle' : 'start')
        .attr('font-size', d => 0.25 + 'em')
        .text(d => d.data.name)
        .style("opacity", 0)
      	.transition()
      	.duration(500)
      	.delay(function(d,i) {
        				return treedelay*i; })
      	.style("opacity", 1)
  });



